# Hybrid Logical Clock

Python implementation of Hybrid Logical Clock.

Requires Python version >= 3.7.

You can install this package from [PyPI](https://pypi.org/project/hlcpy/):

```bash
$ pip install hlcpy
```

Based on:
https://www.cse.buffalo.edu/tech-reports/2014-04.pdf

Inspired by:

- https://www.youtube.com/watch?v=iEFcmfmdh2w
- https://github.com/adsharma/hlcpy (based on but heavily rewritten)
- https://bartoszsypytkowski.com/hybrid-logical-clocks/

## TODO

- better docs and usage examples
